Credits
=======

Design, programming
-------------------

Abilian development team: 2012-2013.


Art (images, icons)
-------------------

See links for copyright and licences (usually Creative Commons).

- Background image(s) for login:
  Kevin Dooley `<http://www.flickr.com/photos/pagedooley/>`_.

- File types icons:
  `<http://www.splitbrain.org/projects/file_icons>`_.

- Animal pictures:
  `<http://en.wikipedia.org/wiki/Wikipedia:Featured_pictures/Animals#Animals>`_.

- Group pictures:
  `<http://en.wikipedia.org/wiki/File:Estudiante_INTEC.jpg>`_,
  `<http://en.wikipedia.org/wiki/File:Salesman_-beach_-_bikini-_sun-27Dec2008.jpg>`_,
  `<http://en.wikipedia.org/wiki/File:Cocacola-5cents-1900_edit1.jpg>`_.

- Group Icon (CC Attribution-Noncommercial-No Derivate 3.0):
  `<http://www.iconarchive.com/show/soft-scraps-icons-by-deleket/User-Group-icon.html>`_.
